# Integrations

Here are all the integrations that Daft currently supports. If there are integrations missing from this list, feel free to [open an issue on Github](https://github.com/Eventual-Inc/Daft/issues) or contribute your own with our [User-Defined Data Sources & Sinks](https://docs.getdaft.io/en/stable/io/#user-defined)!


## Catalogs

<div class="grid cards" markdown>

- [**Apache Iceberg**](io/iceberg.md)
- [**AWS Glue**](catalogs/glue.md)
- [**AWS S3Tables**](catalogs/s3tables.md)
- [**Unity Catalog**](catalogs/unity_catalog.md)

</div>

## Tables

<div class="grid cards" markdown>

- [**Apache Iceberg**](io/iceberg.md)
- [**Apache Hudi**](io/hudi.md)
- [**Delta Lake**](io/delta_lake.md)
- [**Hugging Face Datasets**](io/huggingface.md)
<!-- - [**LanceDB**](io/lancedb.md) -->

</div>

## SQL

<div class="grid cards" markdown>

- [**SQL**](io/sql.md)

</div>

## Storage

<div class="grid cards" markdown>

- [**Amazon Web Services (AWS)**](io/aws.md)
- [**Microsoft Azure**](io/azure.md)
<!-- - [**Google Cloud Storage**](io/gcs.md) -->

</div>
